/**
 * Copyright Copyright 2010 Simon Andrews
 *
 *    This file is part of Difference Tracker.
 *
 *    Difference Tracker is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    Difference Tracker is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with Difference Tracker; if not, write to the Free Software
 *    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package uk.ac.bbsrc.babraham.DifferenceTracker.Config;

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;


public class EditDiffFilterPrefs extends JDialog implements ActionListener {

	private DifferenceTrackerPreferences prefs = DifferenceTrackerPreferences.getInstance();
		
	private JTextField minAbsoluteDiff;
	private JTextField differenceFrameOffset;
	private boolean wasCancelled = false;
	
	public EditDiffFilterPrefs () {
		
		setTitle("Difference Filter Preferences");
		setModal(true);
		
		JPanel prefsPanel = new JPanel();
		
		prefsPanel.setLayout(new GridLayout(2,2));
			
		// Min absolute diff
		JLabel minAbsoluteDiffLabel = new JLabel("Minimum difference");
		minAbsoluteDiffLabel.setToolTipText("What is the minimum difference required to keep a pixel");
		prefsPanel.add(minAbsoluteDiffLabel);
		
		minAbsoluteDiff = new JTextField(""+prefs.minAbsoluteDiff());
		prefsPanel.add(minAbsoluteDiff);
		
		// Diff frame offset
		JLabel differenceFrameOffsetLabel = new JLabel("Difference frame offset");
		differenceFrameOffsetLabel.setToolTipText("How many frames back do we look to determine wheter each pixel has changed");
		prefsPanel.add(differenceFrameOffsetLabel);
		
		differenceFrameOffset = new JTextField(""+prefs.differenceFrameOffset());
		prefsPanel.add(differenceFrameOffset);
		
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add(new JScrollPane(prefsPanel),BorderLayout.CENTER);
		
		JPanel buttonPanel = new JPanel();
		JButton cancelButton = new JButton("Cancel");
		cancelButton.setActionCommand("cancel");
		cancelButton.addActionListener(this);
		JButton saveButton = new JButton("Run");
		saveButton.setActionCommand("run");
		saveButton.addActionListener(this);
		buttonPanel.add(cancelButton);
		buttonPanel.add(saveButton);
		
		getContentPane().add(buttonPanel,BorderLayout.SOUTH);
		
		setSize(400,120);
		setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
		setLocationRelativeTo(null);
		setVisible(true);
	}

	public boolean wasCancelled () {
		return wasCancelled;
	}

	public void actionPerformed(ActionEvent ae) {
		if (ae.getActionCommand().equals("cancel")){
			wasCancelled = true;
			setVisible(false);
		}
		else if (ae.getActionCommand().equals("run")) {
			try {
				prefs.setMinAbsoluteDiff(Integer.parseInt(minAbsoluteDiff.getText()));
				prefs.setDifferenceFrameOffset(Integer.parseInt(differenceFrameOffset.getText()));
			}
			catch (NumberFormatException e) {
				JOptionPane.showMessageDialog(this, "All entries must be integers", "Error setting preferences", JOptionPane.ERROR_MESSAGE);
				return;
			}
			catch (IllegalArgumentException e) {
				JOptionPane.showMessageDialog(this, e.getMessage(), "Error setting preferences", JOptionPane.ERROR_MESSAGE);
				return;				
			}
			setVisible(false);
			dispose();
		}
		else {
			throw new IllegalArgumentException("Don't understand the action '"+ae.getActionCommand()+"'");
		}
		
	}
	
	
	
	
}
